@@ -10,8 +10,7 @@
 #include <stdlib.h>
 #include "queue.h"
 
-queue_t
-queue_create(void)
+queue_t queue_create(void)
 {
 	queue_t q;
 
@@ -28,7 +27,6 @@ int queue_insert(queue_t q, queue_element_t e)
 {
 	queue_node_ptr_t newnode;
 
-
 	if (!q)
 		return -1;
 
@@ -53,7 +51,6 @@ int queue_push(queue_t q, queue_element_t e)
 {
 	queue_node_ptr_t newnode;
 
-
 	if (!q)
 		return -1;
 
@@ -74,13 +71,11 @@ int queue_push(queue_t q, queue_element_t e)
 	return 0;
 }
 
-queue_element_t
-queue_remove(queue_t q)
+queue_element_t queue_remove(queue_t q)
 {
 	queue_node_ptr_t node;
 	queue_element_t e;
 
-
 	if (!q)
 		return NULL;
 
@@ -98,8 +93,7 @@ queue_remove(queue_t q)
 	return e;
 }
 
-queue_element_t
-queue_head(queue_t q)
+queue_element_t queue_head(queue_t q)
 {
 	if (!q)
 		return NULL;
@@ -114,7 +108,6 @@ void queue_destroy(queue_t q)
 {
 	queue_node_ptr_t p, temp;
 
-
 	if (!q)
 		return;
 
@@ -133,7 +126,6 @@ int queue_map(queue_t q, int (*f) (queue_element_t, void *), void *vp)
 	queue_node_ptr_t p;
 	int ret;
 
-
 	if (!q)
 		return 0;
 
@@ -147,16 +139,13 @@ int queue_map(queue_t q, int (*f) (queue_element_t, void *), void *vp)
 	return 0;
 }
 
-
 void queue_map_remove_on_error(queue_t q,
 			       int (*f) (queue_element_t, void *),
-			       void (*g) (queue_element_t, void *),
-			       void *vp)
+			       void (*g) (queue_element_t, void *), void *vp)
 {
 	queue_node_ptr_t p, last, temp;
 	int ret;
 
-
 	if (!q)
 		return;
 
@@ -188,6 +177,4 @@ void queue_map_remove_on_error(queue_t q,
 	return;
 }
 
-
 /* FLASK */
-
